@@ -6,10 +6,10 @@ from reactivity.computed.utils import is_computed_ref
 from reactivity.effect.definations import ReactiveEffectDef
 from reactivity.effect.utils import track_effects, trigger_effects
 from reactivity.effect.vars import active_effect_stack
-from reactivity.env import DEV
+from reactivity.env import DEBUG
 from reactivity.flags import FLAG_OF_REF, REF_VALUE
 from reactivity.reactive import reactive
-from reactivity.reactive.utils import reactive_reversed_class_map
+from reactivity.reactive.utils import reactive_reversed_class_map, to_raw
 
 from .definitions import Ref
 from .utils import deep_unref, is_ref, unref
@@ -30,7 +30,7 @@ def track_ref(obj: object, key: str) -> None:
         return
     if not hasattr(obj, 'deps'):
         return
-    if DEV:
+    if DEBUG:
         print(f'[{"ComputedRef" if is_computed_ref(obj) else "Ref"}] track: self={obj} at {hex(id(obj))} ({id(obj)})')
     deps: Dict[Union[str, int], Set[ReactiveEffectDef[Any]]] = getattr(obj, 'deps')
     if key not in deps:
@@ -45,7 +45,7 @@ def trigger_ref(obj: object, key: str) -> None:
     deps_dict: Dict[Union[str, int], Set[ReactiveEffectDef[Any]]] = getattr(obj, 'deps')
     if key in deps_dict:
         trigger_effects(deps_dict[key])
-    if DEV:
+    if DEBUG:
         print(f'[Ref] trigger: self={obj} at {hex(id(obj))} ({id(obj)})')
 
 
@@ -54,21 +54,20 @@ class RefImpl(Generic[T]):
     deps: Dict[Union[str, int], Set[ReactiveEffectDef[Any]]]
 
     def __init__(self, value: T) -> None:
-        if is_ref(value):
-            raise TypeError(f'TypeError: Cannot create ref from ref. {value} is already a ref.')
-        self.__value = reactive(value)
+        self.__value = to_raw(unref(value))
         self.deps = {}
         setattr(self, FLAG_OF_REF, True)
 
     @property
     def value(self) -> T:
         track_ref_value(self)
-        return self.__value
+        return reactive(self.__value)
 
     @value.setter
     def value(self, value: T) -> None:
-        new_value = reactive(value)
-        if new_value == self.__value:
+        old_value = to_raw(self.__value)
+        new_value = to_raw(unref(value))
+        if new_value == old_value:
             return
         self.__value = new_value
         trigger_ref_value(self)
